Struct ZwpPrimarySelectionDeviceV1
pub struct ZwpPrimarySelectionDeviceV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
zwp_primary_selection_device_v1
See also the Event enum for this interface.
Implementations
impl ZwpPrimarySelectionDeviceV1
impl ZwpPrimarySelectionDeviceV1
pub fn set_selection(
&self,
source: Option<&ZwpPrimarySelectionSourceV1>,
serial: u32,
)
pub fn set_selection( &self, source: Option<&ZwpPrimarySelectionSourceV1>, serial: u32, )
set the primary selection
Replaces the current selection. The previous owner of the primary selection will receive a wp_primary_selection_source.cancelled event.
To unset the selection, set the source to NULL.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the primary selection device
Destroy the primary selection device.